from templer.core.vars import var
from inigo.templer.localcommands import SubTemplate

class UpgradeProfile(SubTemplate):
    """
    Adds an upgrade profile and handler 
    """

    _template_dir = 'templates/genericsetup/upgrade_profile'
    summary = 'Adds an upgrade profile and handler skeleton'

    vars = [
        var('upgrade_from_version', 'Profile version to upgrade from', default='*'),
        var('upgrade_to_version', 'Profile version to upgrade to'),
    ]


class SkinLayer(SubTemplate):
    """
    Adds a skin layer
    """

    _template_dir = 'templates/genericsetup/skin_layer'
    summary = 'Adds a skin layer directory'

    vars = [
        var('default_skin', 'Default skin to inherit from', default='Sunburst Theme')
    ]



from templer.core.vars import var
from inigo.templer.localcommands import SubTemplate
import copy

class PortletSubTemplate(SubTemplate):


    vars = [
        var('portlet_name', 'Portlet name', default='Example Portlet'),
        var('portlet_description', 'Portlet description')
    ]

    def pre(self, command, output_dir, vars):
        super(PortletSubTemplate, self).pre(command, output_dir, vars)
        vars['portlet_classname'] = vars['portlet_name'].replace(" ", "")
        vars['portlet_interfacename'] = 'I' + vars['portlet_classname']
        vars['portlet_filename'] = vars['portlet_classname'].lower()
        vars['portlet_id'] = '%s.portlet.%s' % (vars['package_dotted_name'],
                                                vars['portlet_classname'])

class BasicPortlet(PortletSubTemplate):
    
    _template_dir = 'templates/portlet/basic'
    summary = 'Adds a basic portlet skeleton'


class NonConfigurablePortlet(PortletSubTemplate):
    _template_dir = 'templates/portlet/nonconfigurable'
    summary = 'Adds a nonconfigurable portlet skeleton'

    vars = copy.deepcopy(PortletSubTemplate.vars)
    vars.append(
        var(
            'portlet_contenttypes', 
            'Content types to automatically assign to (comma separated list)',
        )
    )
    vars.append(
        var('portlet_assignmentcolumn',
            'Column of contenttype to automatically assign this portlet to',
            default='plone.rightcolumn')
    )

    def pre(self, command, output_dir, vars):
        super(NonConfigurablePortlet, self).pre(command, output_dir, vars)
        vars['portlet_contenttype_list'] = []
        for i in vars['portlet_contenttypes'].strip().split(','):
            if i:
                vars['portlet_contenttype_list'].append(i)



import copy

from templer.zope import BasicZope
from templer.core.vars import StringVar, EASY, EXPERT

from templer.localcommands import SUPPORTS_LOCAL_COMMANDS
from templer.localcommands import LOCAL_COMMANDS_MESSAGE


class InigoPlone(BasicZope):
    _template_dir = 'templates/inigo_plone'
    summary = 'A comprehensive Plone package for Inigo projects'
    help = '''
This template support local commands. These commands allow you 
to generate skeleton contenttype, behavior, upgrade profiles, 
schemaextender, etc, etc. All that common in Inigo's line of
work
'''
    post_run_msg = LOCAL_COMMANDS_MESSAGE
    category = 'Plone Development'
    use_cheetah = True
    use_local_commands = True
    required_templates = []
    default_required_structures = []
    vars = copy.deepcopy(BasicZope.vars)
    vars.insert(1, StringVar(
        'title',
        title='Project Title',
        description='Title of the project',
        modes=(EASY, EXPERT),
        default='Example Name',
        help="""
This becomes the title of the project. It is used in the
GenericSetup registration for the project and, as such, appears
in Plone's Add/Remove products form.
""",
    ))

    def pre(self, command, output_dir, vars):
        super(InigoPlone, self).pre(command, output_dir, vars)
        vars['use_localcommands'] = self.use_local_commands
        vars['author'] = 'Inigo Consulting'
        vars['author_email'] = 'team@inigo-tech.com'
        vars['url'] = 'http://github.com/inigoconsulting/'



from templer.core.vars import var
from inigo.templer.localcommands import SubTemplate

class SchemaExtender(SubTemplate):

    _template_dir = 'templates/archetypes/schemaextender'
    summary = 'Adds an archetype schemaextender skeleton'

    vars = [
        var('schemaextender_name', 'SchemaExtender name', 
            default='Example Extender'),
    ]

    def pre(self, command, output_dir, vars):
        vars['schemaextender_class_filename'] = vars['schemaextender_name'].replace(" ", "_").lower()
        vars['schemaextender_classname'] = vars['schemaextender_name'].replace(" ", "")



from setuptools import setup, find_packages
import os

version = '1.0'

long_description = (
    open('README.rst').read()
    + '\n' +
    'Contributors\n'
    '============\n'
    + '\n' +
    open('CONTRIBUTORS.txt').read()
    + '\n' +
    open('CHANGES.txt').read()
    + '\n')

setup(name='inigo.templer',
      version=version,
      description="Convenience templer templates for Inigo stuff",
      long_description=long_description,
      # Get more strings from
      # http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Development Status :: 3 - Alpha",
        "Framework :: Zope2",
        "Framework :: Zope3",
        "Framework :: Plone",
        "Framework :: Plone :: 4.1",
        "Framework :: Plone :: 4.2",
        "Framework :: Plone :: 4.3",
        "Framework :: Buildout",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Code Generators",
        ],
      keywords='',
      author='Inigo Consulting',
      author_email='team@inigo-tech.com',
      url='http://github.com/inigoconsulting/inigo.templer',
      license='MIT',
      packages=find_packages(),
      namespace_packages=['inigo'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'templer.core',
          'templer.zope',
          'templer.localcommands',
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      [paste.paster_create_template]
      inigo_plone = inigo.templer:InigoPlone

      [templer.templer_sub_template]
      content_type = inigo.templer.localcommands.dexterity:DexterityContent
      behavior = inigo.templer.localcommands.dexterity:DexterityBehavior
      upgrade_profile = inigo.templer.localcommands.genericsetup:UpgradeProfile
      skin_layer = inigo.templer.localcommands.genericsetup:SkinLayer
      schemaextender = inigo.templer.localcommands.archetypes:SchemaExtender
      basic_portlet = inigo.templer.localcommands.portlet:BasicPortlet
      nonconfigurable_portlet = inigo.templer.localcommands.portlet:NonConfigurablePortlet
      """,
      )
